@@ -1,9 +1,6 @@
 import platform
 import requests
 
-CHAT_ID = '238741623'
-BOT_TOKEN = '1386719865:AAG1pim7Di8pUOJYOgh_tUMLGTLI2BPHk9Q'
-
 
 def send(message: str, chat_id: int, bot_token: str):
     payload = {
@@ -17,4 +14,4 @@ def send(message: str, chat_id: int, bot_token: str):
 
 
 if __name__ == '__main__':
-    send('hello', CHAT_ID, BOT_TOKEN)
+    pass
